==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/baremetal/baremetaldeviceconfigurationwizard.h <==
/****************************************************************************
**
** Copyright (C) 2013 Tim Sander <tim@krieglstein.org>
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef BAREMETALDEVICECONFIGURATIONWIZARD_H
#define BAREMETALDEVICECONFIGURATIONWIZARD_H

#include <projectexplorer/devicesupport/idevice.h>
#include <utils/wizard.h>

namespace BareMetal {
namespace Internal {
   class BareMetalDeviceConfigrationWizardPrivate;
} // namespace Internal

class BareMetalDeviceConfigurationWizard : public Utils::Wizard
{
    Q_OBJECT
public:
    BareMetalDeviceConfigurationWizard(QWidget *parent = 0);
    ~BareMetalDeviceConfigurationWizard();

    ProjectExplorer::IDevice::Ptr device() const;

private:
    Internal::BareMetalDeviceConfigrationWizardPrivate * const d;

};

} //namespace BareMetal

#endif // BAREMETALDEVICECONFIGURATIONWIZARD_H

==> qt-creator-opensource-src-3.2.1.zip: qt-creator-opensource-src-3.2.1/src/plugins/baremetal/baremetaldeviceconfigurationwizard.h <==
/****************************************************************************
**
** Copyright (C) 2014 Tim Sander <tim@krieglstein.org>
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef BAREMETALDEVICECONFIGURATIONWIZARD_H
#define BAREMETALDEVICECONFIGURATIONWIZARD_H

#include <projectexplorer/devicesupport/idevice.h>
#include <utils/wizard.h>

namespace BareMetal {
namespace Internal {

class BareMetalDeviceConfigurationWizardSetupPage;

class BareMetalDeviceConfigurationWizard : public Utils::Wizard
{
    Q_OBJECT

public:
    BareMetalDeviceConfigurationWizard(QWidget *parent = 0);

    ProjectExplorer::IDevice::Ptr device() const;

private:
    BareMetalDeviceConfigurationWizardSetupPage *m_setupPage;
};

} // namespace Internal
} // namespace BareMetal

#endif // BAREMETALDEVICECONFIGURATIONWIZARD_H
